@@ -20,7 +20,6 @@ from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -435,5 +434,8 @@ class MigrationServiceGrpcAsyncIOTransport(MigrationServiceTransport):
             )
         return self._stubs["list_migration_subtasks"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("MigrationServiceGrpcAsyncIOTransport",)
